{pkgs, ...}: {
  programs.plasma = {
    enable = true;
    # overrideConfig = true;

    configFile = import ./configFile.nix;
    panels = import ./panels.nix;

    workspace = {
      clickItemTo = "select";
      lookAndFeel = "org.kde.breezedark.desktop";
      wallpaper = "${pkgs.libsForQt5.plasma-workspace-wallpapers}/share/wallpapers/MilkyWay/contents/images/1080x1920.png";
    };
    kwin.virtualDesktops = {
      rows = 1;
      number = 6;
      names = ["Web" "Main" "Comm" "Aux1" "Aux2" "Music"];
    };
    kwin.borderlessMaximizedWindows = true;
    kwin.nightLight = {
      enable = true;
      mode = "location";
      location.latitude = "37.9755648";
      location.longitude = "23.7348324";
    };
    powerdevil.AC = {
      # Common
      powerButtonAction = "lockScreen";
      whenLaptopLidClosed = "turnOffScreen";
      dimDisplay.enable = true;
      turnOffDisplay.idleTimeoutWhenLocked = 20;
      whenSleepingEnter = "standby";
      # Not common
      autoSuspend.action = "nothing";
      # dimDisplay.idleTimeOut = 120;
      turnOffDisplay.idleTimeout = 300;
    };
    powerdevil.battery = {
      # Common
      powerButtonAction = "lockScreen";
      whenLaptopLidClosed = "turnOffScreen";
      dimDisplay.enable = true;
      turnOffDisplay.idleTimeoutWhenLocked = 20;
      whenSleepingEnter = "standby";
      # Not common
      autoSuspend = {
        action = "sleep";
        idleTimeout = 300;
      };
      turnOffDisplay.idleTimeout = 300;
      # dimDisplay.idleTimeOut = 120;
    };
    powerdevil.lowBattery = {
      # Common
      powerButtonAction = "lockScreen";
      whenLaptopLidClosed = "turnOffScreen";
      dimDisplay.enable = true;
      turnOffDisplay.idleTimeoutWhenLocked = 20;
      whenSleepingEnter = "standby";
      # Not common
      autoSuspend = {
        action = "sleep";
        idleTimeout = 120;
      };
      turnOffDisplay.idleTimeout = 60;
      # dimDisplay.idleTimeOut = 20;
    };
    window-rules = [
      {
        description = "Firefox";
        match.window-class.value = "firefox-devedition";
        apply = {
          desktops = 1;
          maximizehoriz = true;
          maximizevert = true;
        };
      }
      {
        description = "Thunderbird";
        match.window-class.value = "Mail thunderbird";
        apply = {
          desktops = 3;
          maximizehoriz = true;
          maximizevert = true;
        };
      }
    ];

    shortcuts = {
      ksmserver = {
        "Lock Session" = ["Meta+L"];
      };

      kwin = {
        "Switch to Desktop 1" = "Ctrl+F1";
        "Switch to Desktop 2" = "Ctrl+F2";
        "Switch to Desktop 3" = "Ctrl+F3";
        "Switch to Desktop 4" = "Ctrl+F4";
        "Switch to Desktop 5" = "Ctrl+F5";
        "Switch to Desktop 6" = "Ctrl+F6";
        "Window Close" = "Meta+Q";
      };

      org_kde_powerdevil = {
        "Sleep" = ["Sleep" "Meta+Shift+S"];
      };
      "services/firefox-devedition.desktop"."_launch" = "Meta+F";
      "services/Alacritty.desktop"."_launch" = "Meta+Return";
    };
  };
}
